@@ -1,5 +1,4 @@
-"""
-Python module for communicating with a Midas server
+"""Python module for communicating with a Midas server
 """
 __all__ = ['drivers', 'core', 'exceptions']
 
@@ -13,13 +12,20 @@ import hashlib
 pydas.communicator = None
 pydas.email = None
 pydas.api_key = None
+pydas.application = None
 pydas.token = None
 pydas.item_upload_callbacks = []
-pydas.version = '0.2.6'
+pydas.version = '0.2.8'
 
-def login(email=None, password=None, api_key=None, url=None):
-    """
-    Do the legwork of logging into Midas, storing the api_key and token
+def login(email=None, password=None, api_key=None, application='Default', url=None):
+    """Do the legwork of logging into Midas, storing the api_key and token
+
+    :param email: (optional) Email address to login with. If not set, the console will be prompted.
+    :param password: (optional) User password to login with. If not set and no 'api_key' is set, the console will be prompted.
+    :param api_key: (optional) API key to login with. If not set, password login with be used.
+    :param application: (optional) Application name to be used with 'api_key'.
+    :param url: (optional) URL address of the Midas server to login to. If not set, the console will be prompted.
+    :returns: API token.
     """
     if url is None:
         url = raw_input('Server URL: ')
@@ -27,26 +33,27 @@ def login(email=None, password=None, api_key=None, url=None):
     pydas.communicator = pydas.core.Communicator(url)
 
     if email is None:
-        pydas.email = raw_input('Email: ')
-    else:
-        pydas.email = email
+        email = raw_input('Email: ')
+    pydas.email = email
+
     if api_key is None:
         if password is None:
-            pydas.password = getpass.getpass('Password: ')
-        else:
-            pydas.password = password
+            password = getpass.getpass('Password: ')
         pydas.api_key = pydas.communicator.get_default_api_key(pydas.email,
-                                                               pydas.password)
+                                                               password)
+        pydas.application = 'Default'
     else:
         pydas.api_key = api_key
+        pydas.application = application
 
     return renew_token()
 
 def renew_token():
+    """Renew or get a token to use for transactions with Midas.
+
+    :returns: API token.
     """
-    Renew or get a token to use for transactions with Midas.
-    """
-    pydas.token = pydas.communicator.login_with_api_key(pydas.email, pydas.api_key)
+    pydas.token = pydas.communicator.login_with_api_key(pydas.email, pydas.api_key, application=pydas.application)
     return pydas.token
 
 
@@ -65,33 +72,33 @@ def add_item_upload_callback(callback):
 
 
 def _create_or_reuse_item(local_file, parent_folder_id, reuse_existing=False):
-    """Create an item from the local_file in the midas folder corresponding to 
+    """Create an item from the local_file in the midas folder corresponding to
     the parent_folder_id.
 
     :param local_file: full path to a file on the local file system
     :param parent_folder_id: id of parent folder in Midas, where the item will be added
     :param reuse_existing: boolean indicating whether to accept an existing item
     of the same name in the same location, or create a new one instead
-    """ 
+    """
     local_item_name = os.path.basename(local_file)
-    item_id = None 
+    item_id = None
     if reuse_existing:
         # check by name to see if the item already exists in the folder
         children = pydas.communicator.folder_children(pydas.token, parent_folder_id)
         items = children['items']
-     
+
         for item in items:
             if item['name'] == local_item_name:
                 item_id = item['item_id']
                 break
-     
+
     if item_id is None:
         # create the item for the subdir
         new_item = pydas.communicator.create_item(pydas.token,
                                                   local_item_name,
                                                   parent_folder_id)
         item_id = new_item['item_id']
-    
+
     return item_id
 
 def _streaming_file_md5(file_path):
@@ -99,11 +106,11 @@ def _streaming_file_md5(file_path):
     stream the file, rather than load it all into memory.
 
     :param file_path: full path to the file
-    """ 
+    """
     md5 = hashlib.md5()
-    with open(file_path,'rb') as f: 
+    with open(file_path,'rb') as f:
         # iter needs an empty byte string for the returned iterator to halt at EOF
-        for chunk in iter(lambda: f.read(128 * md5.block_size), b''): 
+        for chunk in iter(lambda: f.read(128 * md5.block_size), b''):
             md5.update(chunk)
     return md5.hexdigest()
 
@@ -111,7 +118,7 @@ def _streaming_file_md5(file_path):
 
 def _create_bitstream(filepath, local_file, item_id, log_ind = None):
     """Create a bitstream in the given midas item.
-    
+
     :param filepath: full path to the local file
     :param local_file: name of the local file
     :param log_ind: any additional message to log upon creation of the bitstream
@@ -125,14 +132,14 @@ def _create_bitstream(filepath, local_file, item_id, log_ind = None):
     if upload_token != "":
         log_trace = "Uploading Bitstream from %s" % (filepath)
         # only need to peform the upload if we haven't uploaded before
-        # in this cae, the upload token would not be empty 
+        # in this cae, the upload token would not be empty
         pydas.communicator.perform_upload(upload_token,
                                           local_file,
-                                          filepath = filepath,
-                                          itemid = item_id)
+                                          filepath=filepath,
+                                          itemid=item_id)
     else:
         log_trace = "Adding a bitstream link in this item to an existing bitstream from %s" % (filepath)
-        
+
     if log_ind is not None:
         log_trace = log_trace + log_ind
     print log_trace
@@ -140,8 +147,7 @@ def _create_bitstream(filepath, local_file, item_id, log_ind = None):
 
 
 def _upload_as_item(local_file, parent_folder_id, file_path, reuse_existing=False):
-    """
-    Function for doing an upload of a file as an item. This should be a
+    """Function for doing an upload of a file as an item. This should be a
     building block for user-level functions.
 
     :param local_file: name of local file to upload
@@ -157,8 +163,7 @@ def _upload_as_item(local_file, parent_folder_id, file_path, reuse_existing=Fals
         callback(pydas.communicator, pydas.token, current_item_id)
 
 def _create_folder(local_folder, parent_folder_id):
-    """
-    Function for creating a remote folder and returning the id. This should
+    """Function for creating a remote folder and returning the id. This should
     be a building block for user-level functions.
 
     :param local_folder: full path to a local folder
@@ -173,8 +178,7 @@ def _upload_folder_recursive(local_folder,
                              parent_folder_id,
                              leaf_folders_as_items=False,
                              reuse_existing=False):
-    """
-    Function to recursively upload a folder and all of its descendants.
+    """Function to recursively upload a folder and all of its descendants.
 
     :param local_folder: full path to local folder to be uploaded
     :param parent_folder_id: id of parent folder in Midas, where the new folder will be added
@@ -187,7 +191,7 @@ def _upload_folder_recursive(local_folder,
         _upload_folder_as_item(local_folder, parent_folder_id, reuse_existing)
         return
     else:
-        # do not need to check if folder exists, if it does, an attempt to 
+        # do not need to check if folder exists, if it does, an attempt to
         # create it will just return the existing id
         print 'Creating Folder from %s' % local_folder
         new_folder_id = _create_folder(local_folder, parent_folder_id)
@@ -212,7 +216,7 @@ def _upload_folder_recursive(local_folder,
 def _has_only_files(local_folder):
     """Returns whether a folder has only files. This will be false if the
     folder contains any subdirectories.
- 
+
     :param local_folder: full path to the local folder
     """
     return not any(os.path.isdir(os.path.join(local_folder, entry))
@@ -242,8 +246,7 @@ def _upload_folder_as_item(local_folder, parent_folder_id, reuse_existing=False)
         callback(pydas.communicator, pydas.token, item_id)
 
 def upload(file_pattern, destination = 'Private', leaf_folders_as_items=False, reuse_existing=False):
-    """
-    Upload a pattern of files. This will recursively walk down every tree in
+    """Upload a pattern of files. This will recursively walk down every tree in
     the file pattern to create a hierarchy on the server. As of right now, this
     places the file into the currently logged in user's home directory.
 
