@@ -1,17 +1,14 @@
-"""
-Module for the main user classes for pydas.
+"""Module for the main user classes for pydas.
 """
 import pydas.drivers
 import pydas.exceptions
 
 class Communicator(object):
-    """
-    Class for communicating with the Midas server through its drivers.
+    """Class for communicating with the Midas server through its drivers.
     """
 
     def __init__(self, url, drivers=None):
-        """
-        Constructor that takes a Midas url and an optional list of drivers
+        """Constructor that takes a Midas url and an optional list of drivers
         to use
         """
         if drivers is None:
@@ -29,8 +26,7 @@ class Communicator(object):
         self._url = url
 
     def __getattr__(self, name):
-        """
-        Called when a function does not exist in the class. We pass it down
+        """Called when a function does not exist in the class. We pass it down
         to one of the registered drivers.
         """
         for driver in self.drivers:
@@ -41,15 +37,13 @@ class Communicator(object):
 
     @property
     def drivers(self):
-        """
-        Get the list of drivers
+        """Get the list of drivers
         """
         return self._drivers
 
     @property
     def url(self):
-        """
-        Getter for the url.
+        """Getter for the url.
         """
         if len(self.drivers) > 0:
             return self.drivers[0].url
@@ -58,16 +52,14 @@ class Communicator(object):
 
     @url.setter
     def url(self, value):
-        """
-        Setter for the url.
+        """Setter for the url.
         """
         for driver in self.drivers:
             driver.url = value
 
     @url.deleter
     def url(self):
-        """
-        Delete the url.
+        """Delete the url.
         """
         del self._url
 
